Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ObjectBucketClaimLister ¶
type ObjectBucketClaimLister interface {
// List lists all ObjectBucketClaims in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ObjectBucketClaim, err error)
// ObjectBucketClaims returns an object that can list and get ObjectBucketClaims.
ObjectBucketClaims(namespace string) ObjectBucketClaimNamespaceLister
ObjectBucketClaimListerExpansion
}
ObjectBucketClaimLister helps list ObjectBucketClaims. All objects returned here must be treated as read-only.
func NewObjectBucketClaimLister ¶
func NewObjectBucketClaimLister(indexer cache.Indexer) ObjectBucketClaimLister
NewObjectBucketClaimLister returns a new ObjectBucketClaimLister.
type ObjectBucketClaimListerExpansion ¶
type ObjectBucketClaimListerExpansion interface{}
ObjectBucketClaimListerExpansion allows custom methods to be added to ObjectBucketClaimLister.
type ObjectBucketClaimNamespaceLister ¶
type ObjectBucketClaimNamespaceLister interface {
// List lists all ObjectBucketClaims in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ObjectBucketClaim, err error)
// Get retrieves the ObjectBucketClaim from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ObjectBucketClaim, error)
ObjectBucketClaimNamespaceListerExpansion
}
ObjectBucketClaimNamespaceLister helps list and get ObjectBucketClaims. All objects returned here must be treated as read-only.
type ObjectBucketClaimNamespaceListerExpansion ¶
type ObjectBucketClaimNamespaceListerExpansion interface{}
ObjectBucketClaimNamespaceListerExpansion allows custom methods to be added to ObjectBucketClaimNamespaceLister.
type ObjectBucketLister ¶
type ObjectBucketLister interface {
// List lists all ObjectBuckets in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ObjectBucket, err error)
// Get retrieves the ObjectBucket from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ObjectBucket, error)
ObjectBucketListerExpansion
}
ObjectBucketLister helps list ObjectBuckets. All objects returned here must be treated as read-only.
func NewObjectBucketLister ¶
func NewObjectBucketLister(indexer cache.Indexer) ObjectBucketLister
NewObjectBucketLister returns a new ObjectBucketLister.
type ObjectBucketListerExpansion ¶
type ObjectBucketListerExpansion interface{}
ObjectBucketListerExpansion allows custom methods to be added to ObjectBucketLister.